#
# spec file for package gsmartcontrol
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gsmartcontrol
Version:        2.0.2
Release:        1.1
Summary:        Hard Disk Health Inspection Tool
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Hardware/Other
URL:            http://gsmartcontrol.sourceforge.net/
#Source0:        http://downloads.sourceforge.net/%%{name}/%%{version}/%%{name}-%%{version}.tar.bz2
Source0:        https://github.com/ashaduri/gsmartcontrol/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  cmake >= 3.14
BuildRequires:  fdupes
%if 0%{?suse_version} < 1600
BuildRequires:  gcc13
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc
BuildRequires:  gcc-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig
BuildRequires:  polkit
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.4
BuildRequires:  pkgconfig(libpcre)
Requires:       pcre
Requires:       polkit
Requires:       smartmontools >= 5.43
Recommends:     xdg-utils

%description
GSmartControl is a graphical user interface for smartctl, which is a tool for
querying and controlling SMART (Self-Monitoring, Analysis, and Reporting
Technology) data in hard disk drives. It allows inspecting the drive's
SMART data to determine its health, as well as run various tests on it.

%prep
%setup -q

%build
%if 0%{?suse_version} < 1600
export CC=gcc-13
export CXX=g++-13
%endif
%cmake .. -DCMAKE_BUILD_TYPE=Release

%install
%cmake_install
%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}

%files
%doc README.md
%doc %{_defaultdocdir}/%{name}
%license LICENSE.txt LICENSE.LGPL3.txt dependencies/*/*/LICENSE.*
%{_sbindir}/%{name}
%{_bindir}/%{name}-root
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-root.1%{?ext_man}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/polkit-1/actions/org.gsmartcontrol.policy

%changelog
* Fri Mar 14 2025 ecsos <ecsos@opensuse.org>
- Update to 2.0.2
  - Support GCC 11 (and Ubuntu 22.04) by using and vendoring fmt library (#77).
  - Support an option of saving smartctl output to text instead of JSON (#76).
  - Restored pre-2.0.0 runtime support for smartctl < 7.3 (based on Text parser);
    this is an unsupported, old method without NVMe, provided for compatibility only (#77).
  - Restored pre-2.0.0 support for standard (non-extended) self-test log found in very old ATA drives;
    the new JSON parser did not support this previously (#79).
  - Better support for temperature values in JSON parser; this fixes unreasonably large temperature values (#78).
  - Add a tooltip explaining self-test "lifetime hours" wrapping behavior (#73).
  - Windows: Fixed a crash on Windows 7 when opening drive information by using Windows 7-compatible librsvg (#71).
  - Windows: Avoid using non-integer font sizes.
- Changes from 2.0.1
  - Windows: Fixed a crash when saving or opening smartctl data.
- Changes from 2.0.0
  - New JSON-based parser for smartctl output (requires smartctl 7.3+) (#4).
  - Support for NVMe drives (self-tests require smartctl 7.4+) (#4).
  - New "Basic" JSON parser for SCSI, flash, and other non-ATA/NVMe drives.
  - PCRE library is no longer required (the code has been ported to std::regex) (#40).
  - A lot of code has been refactored and modernized using C++17 and C++20 features, removing much of the custom library code.
  - The build process requires a C++20-compliant compiler now (GCC 13+, Clang 17+, Apple Clang 15+).
  - CMake (3.14+) is now used as a build system instead of autotools.
  - GSmartControl is now licensed under GNU GPL 3 only.
  - Icons come from Oxygen project now (LGPL 3+) instead of Crystal project.
  - Documentation in md format comes with the source code ("docs" directory).
  - Support new versions and prereleases of smartctl (#46, #42).
  - Better detection of drive types thanks to the JSON parser.
  - Removed ATA AODC feature, it has been deprecated for a while now.
  - Information window: Some values are aligned and monospaced to improve readability.
  - Fixed command execution popup dialog being on top of all windows (#17).
  - Other minor UI improvements and fixes.
  - Windows: Better support for HiDPI (including fractional scaling).
  - Windows: NSIS package is generated by CPack now.
  - Windows: Packages are built using GitHub CI now.
* Tue Aug  9 2022 ecsos <ecsos@opensuse.org>
- Update to version 1.1.4
  - Fixed a crash when trying to render main window icons which
    have incomplete data;
    this fixes a rare crash when scanning devices (#13).
  - Fixed rendering compatibility issues with newer GTK3 versions.
  - Fixed build system conflict with C++20 version header (#14).
  - Fixed "Running command ..." dialog floating above windows of
    other applications (#17).
  - Fixed a crash when system locale is set to invalid locale.
  - Support Finnish decimal separator
    (backported from the Debian package) (#23).
  - Set LC_NUMERIC=C for smartctl process to avoid locale-dependent
    number formatting (#23).
  - Fixed printing all GTK messages as warnings; the messages are
    sorted by severity now.
  - Add current time to default filename in Save Output dialog.
  - Support macos stat command in file2csource.sh.
  - Fixed a few typos (backported from the Debian package).
  - Windows port now uses Adwaita theme due to issues with win32 theme.
  - Windows port is dpi-aware now.
- Run spec-cleaner.
* Sun Nov 12 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.1.3
  + Fixed gsmartcontrol-root not launching if GDK_* variables are
    not set.
- Version 1.1.2
  + Fixed gsmartcontrol-root not passing GDK_SCALE and
    GDK_DPI_SCALE variables to gsmartcontrol when using PolKit.
  + Fixed blurriness of icons in the main window with GDK_SCALE=2.
  + Tweaked the main window interface.
  + Windows: Show volume labels beside drive letters in icon
    tooltips.
* Mon Oct  2 2017 jengelh@inai.de
- Do not use install-strip so that debuginfo stays usable.
* Wed Sep 27 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.1.1
  + Windows: Use Adwaita GTK+ theme for systems which support
    Classic Windows theme, since the default win32 GTK+ theme is
    broken in it; this includes Windows 7 and Windows Server.
  + Statistics entry values are formatted with commas for
    readability.
  + Moved help information to website.
* Mon Sep 11 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.1.0
  + New Statistics, Temperature Log, Error Recovery, Physical and
    Directory tabs.
  + General tab shows non-SMART device settings as well.
  + Attributes tab shows entries in "brief" format.
  + Error Log tab shows Extended error log by default (if
    supported).
  + Self-Test Log tab now shows Extended self-test log by default
    (if supported).
  + GSmartControl now uses "-x" equivalent for retrieving data (as
    upposed to "-a"); loading "-x" outputs as virtual drives is
    also supported.
  + Implemented ability to copy rows in CSV format from Attribute,
    Statistics and Self-Test Log tables.
  + Implemented "Update Drive Database" functionality.
  + Windows: Drive letters are shown for each drive.
  + Scan time is shown under virtual drive icons.
  + Polkit is supported with gsmartcontrol-root script now.
  + Pcrecpp is no longer bundled, use system-installed one instead.
  + Smartmontools version 5.43 is required at runtime.
  + Other minor improvements and fixes.
* Mon Jul 24 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.2
  + Fixed incomplete capturing of smartctl output under Windows.
  + Added missing icons under Windows.
  + Fixed being able to turn on AODC even if unsupported.
* Mon Jun 19 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.1
  + Fixed compilation under macOS.
  + Fixed compilation under Fedora Rawhide.
  + Don't use -mtune=generic for all targets.
* Fri Jun 16 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.0
  + Ported to GTK+ 3.
  + Tweaked the user interface a bit.
  + Dropped support for Windows XP, 2000 and 2003 (they are no
    longer supported by GTK+).
  + Fixed detection of newer system-installed smartmontools under
    Windows.
* Tue May 16 2017 joerg.lorenzen@ki.tng.de
- Update to version 0.9.0
  + Implemented (untested) support for Linux-based Areca
    controllers with enclosures.
  + Implemented (untested) support for Windows-based Areca
    controllers (thanks to Richard Kagerer).
  + Implemented (untested) support for Linux-based HP controllers
    with cciss and hpsa/hpahcisr drivers (thanks to
    Fabrice Bacchella).
  + Changes in Preferences no longer fail silently until
    rescan/restart.
  + Better drive detection under Windows after removable drives
    are detached.
  + Windows version is no longer marked as "dpi aware" since it's
    not supported that well.
  + Drive attribute descriptions have been updated (including
    clarifications for SSDs).
  + Added support for SSD-only and HDD-only vendor attributes.
  + Devices having only basic info can be displayed now in the
    info window.
  + Fixed BDRW drive detection (it was detected as a HDD).
  + Other minor improvements.
  + A number of issues have been fixed (including a crash).
* Wed Oct 12 2016 mailaender@opensuse.org
- install licenses
- add missing desktop/icon macros
- recommend xdg-su
* Sun Aug 28 2016 mailaender@opensuse.org
- drop unused and unapplicable gsmartcontrol_parser_crash_fix.diff
* Thu Jun 23 2016 nemysis@openSUSE.org
- Initial package creation
